@@ -228,7 +228,7 @@ static const true_false_string ifcp_flags_spc_tfs = {
 static int
 dissect_ifcpflags(tvbuff_t *tvb, int offset, proto_tree *parent_tree)
 {
-    static const int * flags[] = {
+    static int * const flags[] = {
         &hf_ifcp_flags_ses,
         &hf_ifcp_flags_trp,
         &hf_ifcp_flags_spc,
@@ -247,7 +247,7 @@ dissect_ifcpflags(tvbuff_t *tvb, int offset, proto_tree *parent_tree)
 static void
 dissect_commonflags(tvbuff_t *tvb, int offset, proto_tree *parent_tree)
 {
-    static const int * flags[] = {
+    static int * const flags[] = {
         &hf_ifcp_common_flags_crcv,
         NULL
     };
@@ -426,7 +426,7 @@ dissect_ifcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, voi
     }
 
     next_tvb=tvb_new_subset_length(tvb, offset, frame_len-offset-4);
-    fc_data.ethertype = ETHERTYPE_UNK;
+    fc_data.ethertype = 0;
 
     if(fc_handle){
         call_dissector_with_data(fc_handle, next_tvb, pinfo, parent_tree, &fc_data);
