@@ -105,7 +105,7 @@ static int hf_mmrp_vector_header = -1;
 static int hf_mmrp_leave_all_event = -1;
 static int hf_mmrp_number_of_values = -1;
 static gint ett_vector_header = -1;
-static const int *vector_header_fields[] = {
+static int * const vector_header_fields[] = {
     &hf_mmrp_leave_all_event,
     &hf_mmrp_number_of_values,
     NULL
@@ -313,7 +313,7 @@ dissect_mmrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
                                         MMRP_FIRST_VALUE_GROUP_OFFSET + msg_offset + vect_offset,
                                         attribute_length, ENC_NA);
                     offset = dissect_mmrp_three_packed_event(vect_attr_tree, tvb,
-                                                             MMRP_SERVICE_THREE_PACKED_OFFSET + msg_offset + vect_offset,
+                                                             MMRP_MAC_THREE_PACKED_OFFSET + msg_offset + vect_offset,
                                                              number_of_values);
 
                 }
