@@ -17,7 +17,7 @@
 
 /*
  * This dissector tries to dissect the H.263 protocol according to
- * RFC 2190, http://www.ietf.org/rfc/rfc2190.txt
+ * RFC 2190, https://www.ietf.org/rfc/rfc2190
  */
 
 #include "config.h"
@@ -317,7 +317,7 @@ proto_register_rfc2190(void)
                 FT_BOOLEAN,
                 8,
                 NULL,
-                0x10,
+                0x08,
                 "Picture coding type, intra-coded (false) or inter-coded (true)", HFILL
             }
         },
@@ -329,7 +329,7 @@ proto_register_rfc2190(void)
                 FT_BOOLEAN,
                 8,
                 NULL,
-                0x08,
+                0x10,
                 "Unrestricted Motion Vector option for current picture", HFILL
             }
         },
@@ -341,7 +341,7 @@ proto_register_rfc2190(void)
                 FT_BOOLEAN,
                 8,
                 NULL,
-                0x04,
+                0x20,
                 "Syntax-based Arithmetic Coding option for current picture", HFILL
             }
         },
@@ -353,7 +353,7 @@ proto_register_rfc2190(void)
                 FT_BOOLEAN,
                 8,
                 NULL,
-                0x02,
+                0x40,
                 "Advanced Prediction option for current picture", HFILL
             }
         },
@@ -533,7 +533,7 @@ proto_register_rfc2190(void)
                 FT_UINT16,
                 BASE_DEC,
                 NULL,
-                0x01E0,
+                0x0380,
                 "Reserved field that should contain zeroes", HFILL
             }
         },
@@ -570,7 +570,7 @@ proto_register_rfc2190(void)
     proto_register_subtree_array(ett, array_length(ett));
 
     proto_rfc2190 = proto_register_protocol("H.263 RTP Payload header (RFC2190)",
-        "RFC2190", "rfc2190");
+        "H.263 (RFC2190)", "rfc2190");
 
     proto_register_field_array(proto_rfc2190, hf, array_length(hf));
     rfc2190_handle = register_dissector("rfc2190", dissect_rfc2190, proto_rfc2190);
