@@ -103,7 +103,8 @@ static heur_dtbl_entry_t *heur_dtbl_entry;
 #define CANFD_ESI 0x02 /* error state indicator of the transmitting node */
 
 static dissector_table_t subdissector_table;
-static dissector_handle_t socketcan_classic_handle;
+static dissector_handle_t socketcan_bigendian_handle;
+static dissector_handle_t socketcan_hostendian_handle;
 static dissector_handle_t socketcan_fd_handle;
 
 static const value_string frame_type_vals[] =
@@ -160,66 +161,31 @@ static const value_string can_err_trx_canl_vals[] =
 	{ 0, NULL }
 };
 
-/*
- * Either:
- *
- *    1) a given SocketCAN frame is known to contain a classic CAN
- *       packet based on information outside the SocketCAN header;
- *
- *    2) a given SocketCAN frame is known to contain a CAN FD
- *       packet based on information outside the SocketCAN header;
- *
- *    3) we don't know whether the given SocketCAN frame is a
- *       classic CAN packet or a CAN FD packet, and will have
- *       to check the CANFD_FDF bit in the "FD flags" field of
- *       the SocketCAN headder to determine that.
- */
-typedef enum {
-	PACKET_TYPE_CAN,
-	PACKET_TYPE_CAN_FD,
-	PACKET_TYPE_UNKNOWN
-} can_packet_type_t;
-
 static int
 dissect_socketcan_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
-                         guint encoding, can_packet_type_t can_packet_type)
+						guint encoding)
 {
 	proto_tree *can_tree;
 	proto_item *ti;
 	guint8      frame_type;
 	struct can_info can_info;
-	const int **can_flags;
+	int        * const *can_flags;
 
-	static const int *can_std_flags[] = {
+	static int * const can_std_flags[] = {
 		&hf_can_infoent_std,
 		&hf_can_extflag,
 		&hf_can_rtrflag,
 		&hf_can_errflag,
 		NULL,
 	};
-	static const int *can_ext_flags[] = {
+	static int * const can_ext_flags[] = {
 		&hf_can_infoent_ext,
 		&hf_can_extflag,
 		&hf_can_rtrflag,
 		&hf_can_errflag,
 		NULL,
 	};
-	static const int *can_std_flags_fd[] = {
-		&hf_can_infoent_std,
-		&hf_can_extflag,
-		NULL,
-	};
-	static const int *can_ext_flags_fd[] = {
-		&hf_can_infoent_ext,
-		&hf_can_extflag,
-		NULL,
-	};
-	static const int *canfd_flag_fields[] = {
-		&hf_canfd_brsflag,
-		&hf_canfd_esiflag,
-		NULL,
-	};
-	static const int *can_err_flags[] = {
+	static int * const can_err_flags[] = {
 		&hf_can_errflag,
 		&hf_can_err_tx_timeout,
 		&hf_can_err_lostarb,
@@ -236,43 +202,10 @@ dissect_socketcan_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 	can_info.id = tvb_get_guint32(tvb, 0, encoding);
 	can_info.len = tvb_get_guint8(tvb, CAN_LEN_OFFSET);
-	/*
-	 * If we weren't told the type of this frame, check
-	 * whether the CANFD_FDF flag is set in the FD flags
-	 * field of the header; if so, it's a CAN FD frame.
-	 * otherwise, it's a CAN frame.
-	 *
-	 * However, trust the CANFD_FDF flag only if the only
-	 * bits set in the FD flags field are the known bits,
-	 * and the two bytes following that field are both
-	 * zero.  This is because some older LINKTYPE_CAN_SOCKETCAN
-	 * frames had uninitialized junk in the FD flags field,
-	 * so we treat a frame with what appears to be uninitialized
-	 * junk as being CAN rather than CAN FD, under the assumption
-	 * that the CANFD_FDF bit is set because the field is
-	 * uninitialized, not because it was explicitly set because
-	 * it's a CAN FD frame.  At least some newer code that sets
-	 * that flag also makes sure that the fields in question are
-	 * initialized, so we assume that if they're not initialized
-	 * the code is older code that didn't support CAN FD.
-	 */
-	if (can_packet_type == PACKET_TYPE_UNKNOWN) {
-		guint8 fd_flags;
-
-		fd_flags = tvb_get_guint8(tvb, CANFD_FLAG_OFFSET);
-
-		if ((fd_flags & CANFD_FDF) &&
-		    ((fd_flags & ~(CANFD_BRS|CANFD_ESI|CANFD_FDF)) == 0) &&
-		    tvb_get_guint8(tvb, CANFD_FLAG_OFFSET + 1) == 0 &&
-		    tvb_get_guint8(tvb, CANFD_FLAG_OFFSET + 2) == 0)
-			can_packet_type = PACKET_TYPE_CAN_FD;
-		else
-			can_packet_type = PACKET_TYPE_CAN;
-	}
-	can_info.fd = (can_packet_type == PACKET_TYPE_CAN_FD);
+	can_info.fd = FALSE;
 
 	/* Error Message Frames are only encapsulated in Classic CAN frames */
-	if (can_packet_type == PACKET_TYPE_CAN && (can_info.id & CAN_ERR_FLAG))
+	if (can_info.id & CAN_ERR_FLAG)
 	{
 		frame_type = LINUX_CAN_ERR;
 		can_flags  = can_err_flags;
@@ -281,20 +214,20 @@ dissect_socketcan_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	{
 		frame_type = LINUX_CAN_EXT;
 		can_info.id &= (CAN_EFF_MASK | CAN_FLAG_MASK);
-		can_flags  = (can_packet_type == PACKET_TYPE_CAN_FD) ? can_ext_flags_fd : can_ext_flags;
+		can_flags  = can_ext_flags;
 	}
 	else
 	{
 		frame_type = LINUX_CAN_STD;
 		can_info.id &= (CAN_SFF_MASK | CAN_FLAG_MASK);
-		can_flags  = (can_packet_type == PACKET_TYPE_CAN_FD) ? can_std_flags_fd : can_std_flags;
+		can_flags  = can_std_flags;
 	}
 
-	col_set_str(pinfo->cinfo, COL_PROTOCOL, (can_packet_type == PACKET_TYPE_CAN_FD) ? "CANFD" : "CAN");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "CAN");
 	col_clear(pinfo->cinfo, COL_INFO);
 
-	ti = proto_tree_add_item(tree, (can_packet_type == PACKET_TYPE_CAN_FD) ? proto_canfd : proto_can, tvb, 0, -1, ENC_NA);
-	can_tree = proto_item_add_subtree(ti, (can_packet_type == PACKET_TYPE_CAN_FD) ? ett_can_fd : ett_can);
+	ti = proto_tree_add_item(tree, proto_can, tvb, 0, -1, ENC_NA);
+	can_tree = proto_item_add_subtree(ti, ett_can);
 
 	proto_tree_add_bitmask_list(can_tree, tvb, 0, 4, can_flags, encoding);
 	proto_tree_add_item(can_tree, hf_can_len, tvb, CAN_LEN_OFFSET, 1, ENC_NA);
@@ -302,15 +235,11 @@ dissect_socketcan_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	{
 		proto_tree_add_expert(tree, pinfo, &ei_can_err_dlc_mismatch, tvb, CAN_LEN_OFFSET, 1);
 	}
-	if (can_packet_type == PACKET_TYPE_CAN_FD) {
-		proto_tree_add_bitmask_list(can_tree, tvb, CANFD_FLAG_OFFSET, 1, canfd_flag_fields, ENC_NA);
-		proto_tree_add_item(can_tree, hf_can_reserved, tvb, CANFD_FLAG_OFFSET+1, 2, ENC_NA);
-	} else
-		proto_tree_add_item(can_tree, hf_can_reserved, tvb, CANFD_FLAG_OFFSET, 3, ENC_NA);
+	proto_tree_add_item(can_tree, hf_can_reserved, tvb, CAN_LEN_OFFSET+1, 3, ENC_NA);
 
 	if (frame_type == LINUX_CAN_ERR)
 	{
-		const int **flag;
+		int * const *flag;
 		const char *sepa = ": ";
 
 		col_set_str(pinfo->cinfo, COL_INFO, "ERR");
@@ -334,7 +263,7 @@ dissect_socketcan_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 			proto_tree_add_item(can_tree, hf_can_err_lostarb_bit_number, tvb, CAN_DATA_OFFSET+0, 1, ENC_NA);
 		if (can_info.id & CAN_ERR_CTRL)
 		{
-			static const int *can_err_ctrl_flags[] = {
+			static int * const can_err_ctrl_flags[] = {
 				&hf_can_err_ctrl_rx_overflow,
 				&hf_can_err_ctrl_tx_overflow,
 				&hf_can_err_ctrl_rx_warning,
@@ -349,7 +278,7 @@ dissect_socketcan_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		}
 		if (can_info.id & CAN_ERR_PROT)
 		{
-			static const int *can_err_prot_error_type_flags[] = {
+			static int * const can_err_prot_error_type_flags[] = {
 				&hf_can_err_prot_error_type_bit,
 				&hf_can_err_prot_error_type_form,
 				&hf_can_err_prot_error_type_stuff,
@@ -387,33 +316,9 @@ dissect_socketcan_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		}
 
 		next_tvb = tvb_new_subset_length(tvb, CAN_DATA_OFFSET, can_info.len);
-		if (can_packet_type == PACKET_TYPE_CAN_FD)
+		if (!dissector_try_payload_new(subdissector_table, next_tvb, pinfo, tree, TRUE, &can_info))
 		{
-			if(!heuristic_first)
-			{
-				if (!dissector_try_payload_new(subdissector_table, next_tvb, pinfo, tree, TRUE, &can_info))
-				{
-					if(!dissector_try_heuristic(heur_subdissector_list, next_tvb, pinfo, tree, &heur_dtbl_entry, &can_info))
-					{
-						call_data_dissector(next_tvb, pinfo, tree);
-					}
-				}
-			}
-			else
-			{
-				if (!dissector_try_heuristic(heur_subdissector_list, next_tvb, pinfo, tree, &heur_dtbl_entry, &can_info))
-				{
-					if(!dissector_try_payload_new(subdissector_table, next_tvb, pinfo, tree, FALSE, &can_info))
-					{
-						call_data_dissector(next_tvb, pinfo, tree);
-					}
-				}
-			}
-		} else {
-			if (!dissector_try_payload_new(subdissector_table, next_tvb, pinfo, tree, TRUE, &can_info))
-			{
-				call_data_dissector(next_tvb, pinfo, tree);
-			}
+			call_data_dissector(next_tvb, pinfo, tree);
 		}
 	}
 
@@ -430,29 +335,106 @@ dissect_socketcan_bigendian(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     void* data _U_)
 {
 	return dissect_socketcan_common(tvb, pinfo, tree,
-	    byte_swap ? ENC_LITTLE_ENDIAN : ENC_BIG_ENDIAN, PACKET_TYPE_UNKNOWN);
+	    byte_swap ? ENC_LITTLE_ENDIAN : ENC_BIG_ENDIAN);
 }
 
-#if G_BYTE_ORDER == G_LITTLE_ENDIAN
-    #define ENC_ANTI_HOST_ENDIAN ENC_BIG_ENDIAN
-#else
-    #define ENC_ANTI_HOST_ENDIAN ENC_LITTLE_ENDIAN
-#endif
-
 static int
-dissect_socketcan_classic(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+dissect_socketcan_hostendian(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     void* data _U_)
 {
 	return dissect_socketcan_common(tvb, pinfo, tree,
-	    byte_swap ? ENC_ANTI_HOST_ENDIAN : ENC_HOST_ENDIAN, PACKET_TYPE_CAN);
+	    byte_swap ? ENC_ANTI_HOST_ENDIAN : ENC_HOST_ENDIAN);
+}
+
+static int
+dissect_socketcanfd_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+							guint encoding)
+{
+	proto_tree *can_tree;
+	proto_item *ti;
+	guint8      frame_type;
+	struct can_info can_info;
+	tvbuff_t*   next_tvb;
+	int * can_flags_fd[] = {
+		&hf_can_infoent_ext,
+		&hf_can_extflag,
+		NULL,
+	};
+	static int * const canfd_flag_fields[] = {
+		&hf_canfd_brsflag,
+		&hf_canfd_esiflag,
+		NULL,
+	};
+
+	can_info.id = tvb_get_guint32(tvb, 0, encoding);
+	can_info.len = tvb_get_guint8(tvb, CAN_LEN_OFFSET);
+	can_info.fd = TRUE;
+
+	if (can_info.id & CAN_EFF_FLAG)
+	{
+		frame_type = LINUX_CAN_EXT;
+		can_info.id &= (CAN_EFF_MASK | CAN_FLAG_MASK);
+	}
+	else
+	{
+		frame_type = LINUX_CAN_STD;
+		can_info.id &= (CAN_SFF_MASK | CAN_FLAG_MASK);
+		can_flags_fd[0] = &hf_can_infoent_std;
+	}
+
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "CANFD");
+	col_clear(pinfo->cinfo, COL_INFO);
+
+	col_add_fstr(pinfo->cinfo, COL_INFO, "%s: 0x%08x   %s",
+		     val_to_str(frame_type, frame_type_vals, "Unknown (0x%02x)"), (can_info.id & ~CAN_FLAG_MASK),
+		     tvb_bytes_to_str_punct(wmem_packet_scope(), tvb, CAN_DATA_OFFSET, can_info.len, ' '));
+
+	ti = proto_tree_add_item(tree, proto_canfd, tvb, 0, -1, ENC_NA);
+	can_tree = proto_item_add_subtree(ti, ett_can_fd);
+
+	proto_tree_add_bitmask_list(can_tree, tvb, 0, 4, can_flags_fd, encoding);
+
+	proto_tree_add_item(can_tree, hf_can_len, tvb, CAN_LEN_OFFSET, 1, ENC_NA);
+	proto_tree_add_bitmask_list(can_tree, tvb, CANFD_FLAG_OFFSET, 1, canfd_flag_fields, ENC_NA);
+	proto_tree_add_item(can_tree, hf_can_reserved, tvb, CANFD_FLAG_OFFSET+1, 2, ENC_NA);
+
+	next_tvb = tvb_new_subset_length(tvb, CAN_DATA_OFFSET, can_info.len);
+
+	if(!heuristic_first)
+	{
+		if (!dissector_try_payload_new(subdissector_table, next_tvb, pinfo, tree, TRUE, &can_info))
+		{
+			if(!dissector_try_heuristic(heur_subdissector_list, next_tvb, pinfo, tree, &heur_dtbl_entry, &can_info))
+			{
+				call_data_dissector(next_tvb, pinfo, tree);
+			}
+		}
+	}
+	else
+	{
+		if (!dissector_try_heuristic(heur_subdissector_list, next_tvb, pinfo, tree, &heur_dtbl_entry, &can_info))
+		{
+			if(!dissector_try_payload_new(subdissector_table, next_tvb, pinfo, tree, FALSE, &can_info))
+			{
+				call_data_dissector(next_tvb, pinfo, tree);
+			}
+		}
+	}
+
+	if (tvb_captured_length_remaining(tvb, CAN_DATA_OFFSET+can_info.len) > 0)
+	{
+		proto_tree_add_item(can_tree, hf_can_padding, tvb, CAN_DATA_OFFSET+can_info.len, -1, ENC_NA);
+	}
+
+	return tvb_captured_length(tvb);
 }
 
 static int
 dissect_socketcan_fd(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     void* data _U_)
 {
-	return dissect_socketcan_common(tvb, pinfo, tree,
-	    byte_swap ? ENC_ANTI_HOST_ENDIAN : ENC_HOST_ENDIAN, PACKET_TYPE_CAN_FD);
+	return dissect_socketcanfd_common(tvb, pinfo, tree,
+	    byte_swap ? ENC_ANTI_HOST_ENDIAN : ENC_HOST_ENDIAN);
 }
 
 void
@@ -841,15 +823,8 @@ proto_register_socketcan(void)
 	module_t *can_module;
 
 	proto_can = proto_register_protocol("Controller Area Network", "CAN", "can");
-	/*
-	 * "can-hostendian" is a legacy name (there never was, in any libpcap
-	 * release, a SocketCAN LINKTYPE_ value for a host-endian CAN ID
-	 * and flags field); we need to keep it around in case some candump
-	 * or Busmaster capture that was saved as a pcap or pcapng file,
-	 * as those use a linktype of LINKTYPE_WIRESHARK_UPPER_PDU with
-	 * "can-hostendian" as the dissector name.
-	 */
-	socketcan_classic_handle = register_dissector("can-hostendian", dissect_socketcan_classic, proto_can);
+	socketcan_bigendian_handle = register_dissector("can-bigendian", dissect_socketcan_bigendian, proto_can);
+	socketcan_hostendian_handle = register_dissector("can-hostendian", dissect_socketcan_hostendian, proto_can);
 
 	proto_canfd = proto_register_protocol("Controller Area Network FD", "CANFD", "canfd");
 	socketcan_fd_handle = register_dissector("canfd", dissect_socketcan_fd, proto_canfd);
@@ -881,12 +856,8 @@ proto_register_socketcan(void)
 void
 proto_reg_handoff_socketcan(void)
 {
-	dissector_handle_t socketcan_bigendian_handle;
-
-	socketcan_bigendian_handle = create_dissector_handle(dissect_socketcan_bigendian, proto_can);
 	dissector_add_uint("wtap_encap", WTAP_ENCAP_SOCKETCAN, socketcan_bigendian_handle);
-
-	dissector_add_uint("sll.ltype", LINUX_SLL_P_CAN, socketcan_classic_handle);
+	dissector_add_uint("sll.ltype", LINUX_SLL_P_CAN, socketcan_hostendian_handle);
 	dissector_add_uint("sll.ltype", LINUX_SLL_P_CANFD, socketcan_fd_handle);
 }
 
