@@ -171,7 +171,7 @@ bytes_to_hexstr_punct(char *out, const guint8 *ad, guint32 len, char punct)
 }
 
 /* Max string length for displaying byte string.  */
-#define	MAX_BYTE_STR_LEN	48
+#define	MAX_BYTE_STR_LEN	72
 
 /* Routine to convert a sequence of bytes to a hex string, one byte/two hex
  * digits at at a time, with a specified punctuation character between
@@ -374,35 +374,27 @@ static const gchar *
 get_zonename(struct tm *tmp)
 {
 #if defined(_WIN32)
-	/* Windows C Runtime:                                                 */
-	/*   _tzname is encoded using the "system default ansi code page"     */
-	/*     ("which is not necessarily the same as the C library locale"). */
-	/*     So: _tzname must be converted to UTF8 before use.              */
-	/*   Alternative: use Windows GetTimeZoneInformation() to get the     */
-	/*     timezone name in UTF16 and convert same to UTF8.               */
-	/*   XXX: the result is that the timezone name will be based upon the */
-	/*    system code page (iow: the charset of the system).              */
-	/*    Since Wireshark is not internationalized, it would seem more    */
-	/*    correct to show the timezone name in English, no matter what    */
-	/*    the system code page, but I don't how to do that (or if it's    */
-	/*    really even possible).                                          */
-	/*    In any case converting to UTF8 presumably at least keeps GTK    */
-	/*    happy. (A bug was reported wherein Wireshark crashed in GDK     */
-	/*    on a "Japanese version of Windows XP" when trying to copy       */
-	/*    the date/time string (containing a copy of _tz_name) to the     */
-	/*    clipboard).                                                     */
-	static char *ws_tzname[2] = {NULL, NULL};
-
-	/* The g_malloc'd value returned from g_locale_to_utf8() is   */
-	/*  cached for all further use so there's no need to ever     */
-	/*  g_free() that value.                                      */
-	if (ws_tzname[tmp->tm_isdst] == NULL) {
-		ws_tzname[tmp->tm_isdst] = g_locale_to_utf8(_tzname[tmp->tm_isdst], -1, NULL, NULL, NULL);
-		if (ws_tzname[tmp->tm_isdst] == NULL) {
-			ws_tzname[tmp->tm_isdst] = "???";
-		}
-	}
-	return ws_tzname[tmp->tm_isdst];
+	/*
+	 * The strings in _tzname[] are encoded using the code page
+	 * for the current C-language locale.
+	 *
+	 * On Windows, all Wireshark programs set that code page
+	 * to the UTF-8 code page by calling
+	 *
+	 *	  setlocale(LC_ALL, ".UTF-8");
+	 *
+	 * so the strings in _tzname[] are UTF-8 strings, and we can
+	 * just return them.
+	 *
+	 * (Note: the above does *not* mean we've set any code pages
+	 * *other* than the one used by the Visual Studio C runtime
+	 * to UTF-8, so don't assume, for example, that the "ANSI"
+	 * versions of Windows APIs will take UTF-8 strings, or that
+	 * non-UTF-16 output to the console will be treated as UTF-8.
+	 * Setting those other code pages can cause problems, especially
+	 * on pre-Windows 10 or older Windows 10 releases.)
+	 */
+	return _tzname[tmp->tm_isdst];
 #else
 	/*
 	 * UN*X.
@@ -477,14 +469,34 @@ abs_time_to_str(wmem_allocator_t *scope, const nstime_t *abs_time, const absolut
 				}
 				break;
 			case ABSOLUTE_TIME_NTP_UTC:
-				if ((abs_time->secs == 0) && (abs_time->nsecs == 0)) {
-					buf = wmem_strdup(scope, "NULL");
-					break;
-				}
 				/* FALLTHROUGH */
-
 			case ABSOLUTE_TIME_UTC:
 			case ABSOLUTE_TIME_LOCAL:
+				if ((abs_time->secs == 0) && (abs_time->nsecs == 0)) {
+					if (show_zone) {
+						buf = wmem_strdup_printf(scope,
+							"(0)%s %2d, %d %02d:%02d:%02d.%09ld %s",
+							mon_names[tmp->tm_mon],
+							tmp->tm_mday,
+							tmp->tm_year + 1900,
+							tmp->tm_hour,
+							tmp->tm_min,
+							tmp->tm_sec,
+							(long)abs_time->nsecs,
+							zonename);
+					} else {
+						buf = wmem_strdup_printf(scope,
+							"(0)%s %2d, %d %02d:%02d:%02d.%09ld",
+							mon_names[tmp->tm_mon],
+							tmp->tm_mday,
+							tmp->tm_year + 1900,
+							tmp->tm_hour,
+							tmp->tm_min,
+							tmp->tm_sec,
+							(long)abs_time->nsecs);
+					}
+					break;
+				}
 				if (show_zone) {
 					buf = wmem_strdup_printf(scope,
 							"%s %2d, %d %02d:%02d:%02d.%09ld %s",
@@ -650,13 +662,22 @@ display_epoch_time(gchar *buf, int buflen, const time_t sec, gint32 frac,
 	}
 }
 
+/*
+ * Number of characters required by a 64-bit signed number.
+ */
+#define CHARS_64_BIT_SIGNED	20	/* sign plus 19 digits */
+
+/*
+ * Number of characters required by a fractional part, in nanoseconds */
+#define CHARS_NANOSECONDS	10	/* .000000001 */
+
 void
-display_signed_time(gchar *buf, int buflen, const gint32 sec, gint32 frac,
+display_signed_time(gchar *buf, int buflen, const gint64 sec, gint32 frac,
 		const to_str_time_res_t units)
 {
 	/* this buffer is not NUL terminated */
-	gint8 num_buf[16]; /* max: '-2147483648', '.1000000000' */
-	gint8 *num_end = &num_buf[16];
+	gint8 num_buf[CHARS_64_BIT_SIGNED];
+	gint8 *num_end = &num_buf[CHARS_64_BIT_SIGNED];
 	gint8 *num_ptr;
 	int num_len;
 
@@ -676,7 +697,7 @@ display_signed_time(gchar *buf, int buflen, const gint32 sec, gint32 frac,
 		}
 	}
 
-	num_ptr = int_to_str_back(num_end, sec);
+	num_ptr = int64_to_str_back(num_end, sec);
 
 	num_len = MIN((int) (num_end - num_ptr), buflen);
 	memcpy(buf, num_ptr, num_len);
@@ -924,7 +945,8 @@ rel_time_to_str(wmem_allocator_t *scope, const nstime_t *rel_time)
 	return wmem_strbuf_finalize(buf);
 }
 
-#define REL_TIME_SECS_LEN	(1+10+1+9+1)
+/* Includes terminating '\0' */
+#define REL_TIME_SECS_LEN	(CHARS_64_BIT_SIGNED+CHARS_NANOSECONDS+1)
 
 /*
  * Display a relative time as seconds.
@@ -936,7 +958,7 @@ rel_time_to_secs_str(wmem_allocator_t *scope, const nstime_t *rel_time)
 
 	buf=(gchar *)wmem_alloc(scope, REL_TIME_SECS_LEN);
 
-	display_signed_time(buf, REL_TIME_SECS_LEN, (gint32) rel_time->secs,
+	display_signed_time(buf, REL_TIME_SECS_LEN, (gint64) rel_time->secs,
 			rel_time->nsecs, TO_STR_TIME_RES_T_NSECS);
 	return buf;
 }
