@@ -23,9 +23,19 @@ import fixtures
 @fixtures.mark_usefixtures('test_env')
 @fixtures.uses_fixtures
 class case_decrypt_80211(subprocesstest.SubprocessTestCase):
+    def test_80211_wep(self, cmd_tshark, capture_file):
+        '''IEEE 802.11 WEP'''
+        # Included in git sources test/captures/wep.pcapng.gz
+        self.assertRun((cmd_tshark,
+                '-o', 'wlan.enable_decryption: TRUE',
+                '-r', capture_file('wep.pcapng.gz'),
+                ))
+        self.assertTrue(self.grepOutput('Who has 192.168.5.1'))
+        self.assertTrue(self.grepOutput('Echo \(ping\) request'))
+
     def test_80211_wpa_psk(self, cmd_tshark, capture_file):
         '''IEEE 802.11 WPA PSK'''
-        # https://wiki.wireshark.org/SampleCaptures?action=AttachFile&do=view&target=wpa-Induction.pcap
+        # https://gitlab.com/wireshark/wireshark/-/wikis/SampleCaptures?action=AttachFile&do=view&target=wpa-Induction.pcap
         self.assertRun((cmd_tshark,
                 '-o', 'wlan.enable_decryption: TRUE',
                 '-Tfields',
@@ -289,7 +299,7 @@ class case_decrypt_dtls(subprocesstest.SubprocessTestCase):
         '''DTLS'''
         if not features.have_gnutls:
             self.skipTest('Requires GnuTLS.')
-        # https://wiki.wireshark.org/SampleCaptures?action=AttachFile&do=view&target=snakeoil.tgz
+        # https://gitlab.com/wireshark/wireshark/-/wikis/SampleCaptures?action=AttachFile&do=view&target=snakeoil.tgz
         self.assertRun((cmd_tshark,
                 '-r', capture_file('snakeoil-dtls.pcap'),
                 '-Tfields',
@@ -339,7 +349,7 @@ class case_decrypt_tls(subprocesstest.SubprocessTestCase):
         '''TLS using the server's private RSA key.'''
         if not features.have_gnutls:
             self.skipTest('Requires GnuTLS.')
-        # https://wiki.wireshark.org/SampleCaptures?action=AttachFile&do=view&target=snakeoil2_070531.tgz
+        # https://gitlab.com/wireshark/wireshark/-/wikis/SampleCaptures?action=AttachFile&do=view&target=snakeoil2_070531.tgz
         self.assertRun((cmd_tshark,
                 '-r', capture_file('rsasnakeoil2.pcap'),
                 '-Tfields',
