@@ -37,15 +37,6 @@ def find_test_ids(suite, all_ids):
     else:
         all_ids.append(suite.id())
 
-def dump_failed_output(suite):
-    if hasattr(suite, '__iter__'):
-        for s in suite:
-            dump_failures = getattr(s, 'dump_failures', None)
-            if dump_failures:
-                dump_failures()
-            else:
-                dump_failed_output(s)
-
 def main():
     if sys.version_info[0] < 3:
         print("Unit tests require Python 3")
@@ -54,6 +45,8 @@ def main():
     parser = argparse.ArgumentParser(description='Wireshark unit tests')
     cap_group = parser.add_mutually_exclusive_group()
     cap_group.add_argument('-E', '--disable-capture', action='store_true', help='Disable capture tests')
+    release_group = parser.add_mutually_exclusive_group()
+    release_group.add_argument('--enable-release', action='store_true', help='Enable release tests')
     parser.add_argument('-p', '--program-path', default=os.path.curdir, help='Path to Wireshark executables.')
     parser.add_argument('--skip-missing-programs',
         help='Skip tests that lack programs from this list instead of failing'
@@ -140,8 +133,6 @@ def main():
         # for unittest compatibility (not needed with pytest)
         fixtures_ws.fixtures.destroy_session()
 
-    dump_failed_output(run_suite)
-
     if test_result.errors:
         sys.exit(2)
 
