@@ -1,23 +1,10 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
 #
 # Wireshark - Network traffic analyzer
 # By Gerald Combs <gerald@wireshark.org>
 # Copyright 1998 Gerald Combs
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# SPDX-License-Identifier: GPL-2.0-or-later
 '''Update the "manuf" file.
 
 Make-manuf creates a file containing ethernet OUIs and their company
@@ -32,17 +19,13 @@ the listing in "oui.txt", "iab.txt", etc, with the entries in
 "manuf.tmpl" taking precedence.
 '''
 
+import codecs
 import csv
 import io
 import os
 import re
 import sys
-
-if sys.version_info[0] >= 3:
-    import urllib.request, urllib.error, urllib.parse
-    import codecs
-else:
-    import urllib2
+import urllib.request, urllib.error, urllib.parse
 
 have_icu = False
 try:
@@ -66,19 +49,58 @@ def open_url(url):
     '''
     req_headers = { 'User-Agent': 'Wireshark make-manuf' }
     try:
-        if sys.version_info[0] >= 3:
-            req = urllib.request.Request(url, headers=req_headers)
-            response = urllib.request.urlopen(req)
-            body = response.read().decode('UTF-8', 'replace')
-        else:
-            req = urllib2.Request(url, headers=req_headers)
-            response = urllib2.urlopen(req)
-            body = response.read()
-    except:
+        req = urllib.request.Request(url, headers=req_headers)
+        response = urllib.request.urlopen(req)
+        body = response.read().decode('UTF-8', 'replace')
+    except Exception:
         exit_msg('Error opening ' + url)
 
     return (body, dict(response.info()))
 
+# These are applied after punctuation has been removed.
+# More examples at https://en.wikipedia.org/wiki/Incorporation_(business)
+general_terms = '|'.join([
+    'a/s',
+    'ab', # Also follows "Oy", which is covered below.
+    'ag',
+    'b ?v',
+    'closed joint stock company',
+    'co',
+    'company',
+    'corp',
+    'corporation',
+    'de c ?v', # Follows "S.A.", which is covered separately below.
+    'gmbh',
+    'holding',
+    'inc',
+    'incorporated',
+    'jsc',
+    'kg',
+    'k k', # "K.K." as in "kabushiki kaisha", but not "K+K" as in "K+K Messtechnik".
+    'limited',
+    'llc',
+    'ltd',
+    'n ?v',
+    'oao',
+    'of',
+    'open joint stock company',
+    'ooo',
+    'oy',
+    'oyj',
+    'plc',
+    'pty',
+    'pvt',
+    's ?a ?r ?l',
+    's ?a',
+    's ?p ?a',
+    'sp ?k',
+    's ?r ?l',
+    'systems',
+    'the',
+    'zao',
+    'z ?o ?o'
+    ])
+
 def shorten(manuf):
     '''Convert a long manufacturer name to abbreviated and short names'''
     # Normalize whitespace.
@@ -87,18 +109,26 @@ def shorten(manuf):
     # Add exactly one space on each end.
     # XXX This appears to be for the re.sub below.
     manuf = u' {} '.format(manuf)
-    # Convert to consistent case
-    manuf = manuf.title()
+    # Convert all caps to title case
+    if manuf.isupper():
+        manuf = manuf.title()
     # Remove any punctuation
     # XXX Use string.punctuation? Note that it includes '-' and '*'.
-    manuf = re.sub(u"[',.()]", ' ', manuf)
+    manuf = re.sub(u"[\"',.()]", ' ', manuf)
     # & isn't needed when Standalone
     manuf = manuf.replace(" & ", " ")
-    # Remove any "the", "inc", "plc" ...
-    manuf = re.sub('\W(the|incorporated|inc|plc|systems|corporation|corp|s/a|a/s|ab|ag|kg|gmbh|company|co|limited|ltd|holding|spa)(?= )', '', manuf, flags=re.IGNORECASE)
+    # Remove business types and other general terms ("the", "inc", "plc", etc.)
+    plain_manuf = re.sub('\W(' + general_terms + ')(?= )', '', manuf, flags=re.IGNORECASE)
+    # ...but make sure we don't remove everything.
+    if not all(s == ' ' for s in plain_manuf):
+        manuf = plain_manuf
     # Remove all spaces
     manuf = re.sub('\s+', '', manuf)
 
+    if len(manuf) < 1:
+        sys.stderr.write('Manufacturer "{}" shortened to nothing.\n'.format(orig_manuf))
+        sys.exit(1)
+
     # Truncate names to a reasonable length, say, 8 characters. If
     # the string contains UTF-8, this may be substantially more than
     # 8 bytes. It might also be less than 8 visible characters. Plain
@@ -131,10 +161,10 @@ def shorten(manuf):
     # At least one entry has whitespace in front of a period.
     mixed_manuf = re.sub('\s+\.', '.', mixed_manuf)
     #If company is all caps, convert to mixed case (so it doesn't look like we're screaming the company name)
-    #if mixed_manuf.upper() == mixed_manuf:
-    #    mixed_manuf = mixed_manuf.title()
+    if mixed_manuf.upper() == mixed_manuf:
+        mixed_manuf = mixed_manuf.title()
 
-    return u'{:<22} # {}'.format(manuf, mixed_manuf)
+    return u'{}\t{}'.format(manuf, mixed_manuf)
 
 def prefix_to_oui(prefix):
     pfx_len = len(prefix) * 8 / 2
@@ -149,9 +179,12 @@ def prefix_to_oui(prefix):
     return '{}/{:d}'.format(oui, int(pfx_len))
 
 def main():
+    if sys.version_info[0] < 3:
+        print("This requires Python 3")
+        sys.exit(2)
+
     this_dir = os.path.dirname(__file__)
     template_path = os.path.join(this_dir, '..', 'manuf.tmpl')
-    wka_path = os.path.join(this_dir, '..', 'wka.tmpl')
     manuf_path = os.path.join(this_dir, '..', 'manuf')
     header_l = []
     in_header = True
@@ -175,7 +208,7 @@ def main():
 
     try:
         tmpl_fd = io.open(template_path, 'r', encoding='UTF-8')
-    except:
+    except Exception:
         exit_msg("Couldn't open template file for reading ({}) ".format(template_path))
     for tmpl_line in tmpl_fd:
         tmpl_line = tmpl_line.strip()
@@ -203,12 +236,8 @@ def main():
         print('Merging {} data from {}'.format(db, db_url))
         (body, response_d) = open_url(db_url)
         ieee_csv = csv.reader(body.splitlines())
-        if sys.version_info[0] >= 3:
-            ieee_d[db]['last-modified'] = response_d['Last-Modified']
-            ieee_d[db]['length'] = response_d['Content-Length']
-        else:
-            ieee_d[db]['last-modified'] = response_d['last-modified']
-            ieee_d[db]['length'] = response_d['content-length']
+        ieee_d[db]['last-modified'] = response_d['Last-Modified']
+        ieee_d[db]['length'] = response_d['Content-Length']
 
         # Pop the title row.
         next(ieee_csv)
@@ -216,10 +245,7 @@ def main():
             #Registry,Assignment,Organization Name,Organization Address
             #IAB,0050C2DD6,Transas Marine Limited,Datavagen 37 Askim Vastra Gotaland SE 436 32
             oui = prefix_to_oui(ieee_row[1].upper())
-            if sys.version_info[0] >= 3:
-                manuf = ieee_row[2].strip()
-            else:
-                manuf = ieee_row[2].strip().decode('UTF-8')
+            manuf = ieee_row[2].strip()
             if oui in oui_d:
                 print(u'{} - Skipping IEEE "{}" in favor of "{}"'.format(oui, manuf, oui_d[oui]))
                 ieee_d[db]['skipped'] += 1
@@ -239,11 +265,11 @@ def main():
 
     try:
         manuf_fd = io.open(manuf_path, 'w', encoding='UTF-8')
-    except:
+    except Exception:
         exit_msg("Couldn't open manuf file for reading ({}) ".format(manuf_path))
 
     manuf_fd.write(u"# This file was generated by running ./tools/make-manuf.py.\n")
-    manuf_fd.write(u"# Don't change it directly, change manuf.tmpl and wka.tmpl instead.\n#\n")
+    manuf_fd.write(u"# Don't change it directly, change manuf.tmpl instead.\n#\n")
     manuf_fd.write('\n'.join(header_l))
 
     for db in ieee_db_l:
@@ -260,19 +286,6 @@ def main():
     for oui in oui_l:
         manuf_fd.write(u'{}\t{}\n'.format(oui, oui_d[oui]))
 
-    # Write out a blank line separating the OUIs from the well-known
-    # addresses, and then read the well-known address template file
-    # and write it to the manuf file.
-
-    manuf_fd.write(u'\n')
-    try:
-        wka_fd = io.open(wka_path, 'r', encoding='UTF-8')
-    except:
-        exit_msg("Couldn't open wka template file for reading ({}) ".format(wka_path))
-    for wka_line in wka_fd:
-        wka_line = wka_line.rstrip()
-        manuf_fd.write(u'{}\n'.format(wka_line))
-
     manuf_fd.close()
 
     print('{:<20}: {}'.format('Original entries', tmpl_added))
