@@ -94,8 +94,8 @@ sub read_repo_info {
 
 	# Tarball produced by 'git archive' will have the $Format string
 	# substituted due to the use of 'export-subst' in .gitattributes.
-	my $git_archive_commit = 'd64aca7966e216e0d8ac984004bab7732f263fd1';
-	my @git_refs = split(/, /, 'HEAD -> master, tag: v3.3.1');
+	my $git_archive_commit = '9733f173ea5e6255e8da208ef183210aa264d948';
+	my @git_refs = split(/, /, 'HEAD -> release-3.4, tag: wireshark-3.4.0, tag: v3.4.0');
 	if (substr($git_archive_commit, 0, 1) eq '$') {
 		# If $Format is still present, then this is not a git archive.
 		$git_archive_commit = undef;
