@@ -118,6 +118,7 @@ QString &ImportTextDialog::capfileName() {
 void ImportTextDialog::convertTextFile() {
     char *tmpname;
     int err;
+    gchar *err_info;
     wtap_dump_params params;
 
     capfile_name_.clear();
@@ -126,12 +127,12 @@ void ImportTextDialog::convertTextFile() {
     params.snaplen = import_info_.max_frame_length;
     params.tsprec = WTAP_TSPREC_USEC; /* XXX - support other precisions? */
     /* Use a random name for the temporary import buffer */
-    import_info_.wdh = wtap_dump_open_tempfile(&tmpname, "import", WTAP_FILE_TYPE_SUBTYPE_PCAPNG, WTAP_UNCOMPRESSED, &params, &err);
+    import_info_.wdh = wtap_dump_open_tempfile(&tmpname, "import", WTAP_FILE_TYPE_SUBTYPE_PCAPNG, WTAP_UNCOMPRESSED, &params, &err, &err_info);
     capfile_name_.append(tmpname ? tmpname : "temporary file");
     g_free(tmpname);
     qDebug() << capfile_name_ << ":" << import_info_.wdh << import_info_.encapsulation << import_info_.max_frame_length;
     if (import_info_.wdh == NULL) {
-        cfile_dump_open_failure_alert_box(capfile_name_.toUtf8().constData(), err, WTAP_FILE_TYPE_SUBTYPE_PCAP);
+        cfile_dump_open_failure_alert_box(capfile_name_.toUtf8().constData(), err, err_info, WTAP_FILE_TYPE_SUBTYPE_PCAP);
         fclose(import_info_.import_text_file);
         setResult(QDialog::Rejected);
         return;
@@ -150,9 +151,9 @@ void ImportTextDialog::convertTextFile() {
         read_failure_alert_box(import_info_.import_text_filename, errno);
     }
 
-    if (!wtap_dump_close(import_info_.wdh, &err))
+    if (!wtap_dump_close(import_info_.wdh, &err, &err_info))
     {
-        cfile_close_failure_alert_box(capfile_name_.toUtf8().constData(), err);
+        cfile_close_failure_alert_box(capfile_name_.toUtf8().constData(), err, err_info);
     }
 }
 
