@@ -24,7 +24,7 @@
 #include <ui/qt/models/interface_tree_model.h>
 #include <ui/qt/models/sparkline_delegate.h>
 
-#include <ui/qt/utils/tango_colors.h>
+#include <ui/qt/utils/color_utils.h>
 
 
 #include "extcap.h"
@@ -68,17 +68,7 @@ InterfaceFrame::InterfaceFrame(QWidget * parent)
                       "QTreeView {"
                       "  border: 0;"
                       "}"
-                      "QLabel {"
-                      "  border-radius: 0.5em;"
-                      "  padding: 0.33em;"
-                      "  margin-bottom: 0.25em;"
-                      // We might want to transition this to normal colors this after a timeout.
-                      "  color: #%1;"
-                      "  background-color: #%2;"
-                      "}"
-                    )
-                  .arg(ws_css_warn_text, 6, 16, QChar('0'))
-                  .arg(ws_css_warn_background, 6, 16, QChar('0')));
+                      ));
 
     ui->warningLabel->hide();
 
@@ -278,6 +268,16 @@ void InterfaceFrame::resetInterfaceTreeDisplay()
     ui->warningLabel->hide();
     ui->warningLabel->clear();
 
+    ui->warningLabel->setStyleSheet(QString(
+                "QLabel {"
+                "  border-radius: 0.5em;"
+                "  padding: 0.33em;"
+                "  margin-bottom: 0.25em;"
+                // We might want to transition this to normal colors this after a timeout.
+                "  background-color: %2;"
+                "}"
+                ).arg(ColorUtils::warningBackground().name()));
+
 #ifdef HAVE_LIBPCAP
 #ifdef Q_OS_WIN
     if (!has_wpcap) {
@@ -303,6 +303,12 @@ void InterfaceFrame::resetInterfaceTreeDisplay()
     if (!haveLocalCapturePermissions())
     {
 #ifdef Q_OS_MAC
+        //
+        // NOTE: if you change this text, you must also change the
+        // definition of PLATFORM_PERMISSIONS_SUGGESTION that is
+        // used if __APPLE__ is defined, so that it reflects the
+        // new message text.
+        //
         QString install_chmodbpf_path = wsApp->applicationDirPath() + "/../Resources/Extras/Install ChmodBPF.pkg";
         ui->warningLabel->setText(tr(
             "<p>"
@@ -312,6 +318,11 @@ void InterfaceFrame::resetInterfaceTreeDisplay()
             "</p>")
             .arg(install_chmodbpf_path));
 #else
+        //
+        // XXX - should this give similar platform-dependent recommendations,
+        // just as dumpcap gives platform-dependent recommendations in its
+        // PLATFORM_PERMISSIONS_SUGGESTION #define?
+        //
         ui->warningLabel->setText(tr("You don't have permission to capture on local interfaces."));
 #endif
     }
