@@ -18,6 +18,7 @@
 #include <tchar.h>
 #include <wchar.h>
 #include <shellapi.h>
+#include "ui/win32/console_win32.h"
 #endif
 
 #ifdef HAVE_GETOPT_H
@@ -30,6 +31,7 @@
 
 #include <ui/clopts_common.h>
 #include <ui/cmdarg_err.h>
+#include <ui/urls.h>
 #include <wsutil/filesystem.h>
 #include <wsutil/privileges.h>
 #include <wsutil/socket.h>
@@ -336,7 +338,7 @@ check_and_warn_user_startup()
         "This could be dangerous.\n\n"
         "If you're running Wireshark this way in order to perform live capture, "
         "you may want to be aware that there is a better way documented at\n"
-        "https://wiki.wireshark.org/CaptureSetup/CapturePrivileges", cur_user, cur_group);
+        WS_WIKI_URL("CaptureSetup/CapturePrivileges"), cur_user, cur_group);
         g_free(cur_user);
         g_free(cur_group);
     }
@@ -404,6 +406,42 @@ int main(int argc, char *qt_argv[])
 #endif
     /* Start time in microseconds */
     guint64 start_time = g_get_monotonic_time();
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    /*
+     * See:
+     *
+     *    issue #16908;
+     *
+     *    https://doc.qt.io/qt-5/qvector.html#maximum-size-and-out-of-memory-conditions
+     *
+     *    https://forum.qt.io/topic/114950/qvector-realloc-throwing-sigsegv-when-very-large-surface3d-is-rendered
+     *
+     * for why we're doing this; the widget we use for the packet list
+     * uses QVector, so those limitations apply to it.
+     *
+     * Apparently, this will be fixed in Qt 6:
+     *
+     *    https://github.com/qt/qtbase/commit/215ca735341b9487826023a7983382851ce8bf26
+     *
+     *    https://github.com/qt/qtbase/commit/2a6cdec718934ca2cc7f6f9c616ebe62f6912123#diff-724f419b0bb0487c2629bb16cf534c4b268ddcee89b5177189b607f940cfd83dR192
+     *
+     * Hopefully QList won't cause any performance hits relative to
+     * QVector.
+     *
+     * We pick 53 million records as a value that should avoid the problem;
+     * see the Wireshark issue for why that value was chosen.
+     */
+    cf_set_max_records(53000000);
+#endif
+
+    /* Enable destinations for logging earlier in startup */
+    set_console_log_handler();
+    qInstallMessageHandler(g_log_message_handler);
+#ifdef _WIN32
+    restore_pipes();
+#endif
+
 #ifdef DEBUG_STARTUP_TIME
     /* At least on Windows there is a problem with the logging as the preferences is taken
      * into account and the preferences are loaded pretty late in the startup process.
@@ -463,7 +501,7 @@ int main(int argc, char *qt_argv[])
      * executable file.
      */
     /* init_progfile_dir_error = */ init_progfile_dir(argv[0]);
-    g_log(NULL, G_LOG_LEVEL_DEBUG, "progfile_dir: %s", get_progfile_dir());
+    /* g_log(NULL, G_LOG_LEVEL_DEBUG, "progfile_dir: %s", get_progfile_dir()); */
 
 #ifdef _WIN32
     ws_init_dll_search_path();
@@ -596,7 +634,7 @@ int main(int argc, char *qt_argv[])
     read_language_prefs();
     wsApp->loadLanguage(language);
 
-    g_log(LOG_DOMAIN_MAIN, G_LOG_LEVEL_DEBUG, "Translator %s", language);
+    /* g_log(LOG_DOMAIN_MAIN, G_LOG_LEVEL_DEBUG, "Translator %s", language); */
 
     // Init the main window (and splash)
     main_w = new(MainWindow);
@@ -617,8 +655,6 @@ int main(int argc, char *qt_argv[])
       wsApp->setLastOpenDir(get_persdatafile_dir());
     }
 
-    set_console_log_handler();
-    qInstallMessageHandler(g_log_message_handler);
 #ifdef DEBUG_STARTUP_TIME
     g_log(LOG_DOMAIN_MAIN, G_LOG_LEVEL_INFO, "set_console_log_handler, elapsed time %" G_GUINT64_FORMAT " us \n", g_get_monotonic_time() - start_time);
 #endif
