@@ -32,8 +32,6 @@ public:
     PacketListRecord(frame_data *frameData);
     virtual ~PacketListRecord();
 
-    // Ensure that the record is colorized.
-    void ensureColorized(capture_file *cap_file);
     // Return the string value for a column. Data is cached if possible.
     const QString columnString(capture_file *cap_file, int column, bool colorized = false);
     frame_data *frameData() const { return fdata_; }
@@ -70,6 +68,8 @@ private:
     /** Conversation. Used by RelatedPacketDelegate */
     unsigned int conv_index_;
 
+    bool read_failed_;
+
     void dissect(capture_file *cap_file, bool dissect_color = false);
     void cacheColumnStrings(column_info *cinfo);
 };
