@@ -44,7 +44,8 @@ enum { voip_calls_type_ = 1000 };
 VoipCallsDialog::VoipCallsDialog(QWidget &parent, CaptureFile &cf, bool all_flows) :
     WiresharkDialog(parent, cf),
     ui(new Ui::VoipCallsDialog),
-    parent_(parent)
+    parent_(parent),
+    voip_calls_tap_listeners_removed_(false)
 {
     ui->setupUi(this);
     loadGeometry(parent.width() * 4 / 5, parent.height() * 2 / 3);
@@ -80,7 +81,6 @@ VoipCallsDialog::VoipCallsDialog(QWidget &parent, CaptureFile &cf, bool all_flow
 
     memset (&tapinfo_, 0, sizeof(tapinfo_));
     tapinfo_.tap_packet = tapPacket;
-    tapinfo_.tap_reset = tapReset;
     tapinfo_.tap_draw = tapDraw;
     tapinfo_.tap_data = this;
     tapinfo_.callsinfos = g_queue_new();
@@ -105,14 +105,20 @@ VoipCallsDialog::~VoipCallsDialog()
     delete ui;
 
     voip_calls_reset_all_taps(&tapinfo_);
-    voip_calls_remove_all_tap_listeners(&tapinfo_);
+    if (!voip_calls_tap_listeners_removed_) {
+        voip_calls_remove_all_tap_listeners(&tapinfo_);
+        voip_calls_tap_listeners_removed_ = true;
+    }
     sequence_info_->unref();
     g_queue_free(tapinfo_.callsinfos);
 }
 
 void VoipCallsDialog::removeTapListeners()
 {
-    voip_calls_remove_all_tap_listeners(&tapinfo_);
+    if (!voip_calls_tap_listeners_removed_) {
+        voip_calls_remove_all_tap_listeners(&tapinfo_);
+        voip_calls_tap_listeners_removed_ = true;
+    }
     WiresharkDialog::removeTapListeners();
 }
 
@@ -122,7 +128,10 @@ void VoipCallsDialog::captureFileClosing()
     // the cache is active, the ToD cannot be modified.
     ui->todCheckBox->setEnabled(false);
     cache_model_->setSourceModel(NULL);
-    voip_calls_remove_all_tap_listeners(&tapinfo_);
+    if (!voip_calls_tap_listeners_removed_) {
+        voip_calls_remove_all_tap_listeners(&tapinfo_);
+        voip_calls_tap_listeners_removed_ = true;
+    }
     tapinfo_.session = NULL;
     WiresharkDialog::captureFileClosing();
 }
@@ -167,19 +176,10 @@ void VoipCallsDialog::changeEvent(QEvent *event)
     QDialog::changeEvent(event);
 }
 
-void VoipCallsDialog::tapReset(void *tapinfo_ptr)
-{
-    voip_calls_tapinfo_t *tapinfo = static_cast<voip_calls_tapinfo_t *>(tapinfo_ptr);
-    VoipCallsDialog *voip_calls_dialog = static_cast<VoipCallsDialog *>(tapinfo->tap_data);
-    voip_calls_dialog->call_infos_model_->removeAllCalls();
-    voip_calls_reset_all_taps(tapinfo);
-
-    // Leave old graph_analysis as is and allocate new one
-    voip_calls_dialog->sequence_info_->unref();
-    voip_calls_dialog->tapinfo_.graph_analysis = sequence_analysis_info_new();
-    voip_calls_dialog->tapinfo_.graph_analysis->name = "voip";
-    voip_calls_dialog->sequence_info_ = new SequenceInfo(voip_calls_dialog->tapinfo_.graph_analysis);
-}
+//void VoipCallsDialog::tapReset(void *)
+//{
+//    voip_calls_tapinfo_t *tapinfo = (voip_calls_tapinfo_t *) tapinfo_ptr;
+//}
 
 tap_packet_status VoipCallsDialog::tapPacket(void *, packet_info *, epan_dissect_t *, const void *)
 {
@@ -437,6 +437,7 @@ void VoipCallsDialog::showPlayer()
 
     rtp_player_dialog->setWindowModality(Qt::ApplicationModal);
     rtp_player_dialog->setAttribute(Qt::WA_DeleteOnClose);
+    rtp_player_dialog->setMarkers();
     rtp_player_dialog->show();
 #endif // QT_MULTIMEDIA_LIB
 }
