@@ -48,8 +48,6 @@
 #include "packet_list.h"
 #include <ui/qt/models/packet_list_model.h>
 
-#include "ui/main_statusbar.h"
-
 /* we start rendering this number of microseconds left of the left edge - to ensure
  * NAV lines are drawn correctly, and that small errors in time order don't prevent some
  * frames from being rendered.
@@ -175,7 +173,7 @@ void WirelessTimeline::clip_tsf()
 }
 
 
-void WirelessTimeline::selectedFrameChanged(int)
+void WirelessTimeline::selectedFrameChanged(QList<int>)
 {
     if (isHidden())
         return;
@@ -259,11 +257,13 @@ void WirelessTimeline::captureFileReadFinished()
     for (guint32 n = 1; n < cfile.count; n++) {
         struct wlan_radio *w = get_wlan_radio(n);
         if (w->start_tsf == 0 || w->end_tsf == 0) {
-            statusbar_push_temporary_msg("Packet number %u does not include TSF timestamp, not showing timeline.", n);
+            QString err = tr("Packet number %1 does not include TSF timestamp, not showing timeline.").arg(n);
+            wsApp->pushStatus(WiresharkApplication::TemporaryStatus, err);
             return;
         }
         if (w->ifs < -RENDER_EARLY) {
-            statusbar_push_temporary_msg("Packet number %u has large negative jump in TSF, not showing timeline. Perhaps TSF reference point is set wrong?", n);
+            QString err = tr("Packet number %u has large negative jump in TSF, not showing timeline. Perhaps TSF reference point is set wrong?").arg(n);
+            wsApp->pushStatus(WiresharkApplication::TemporaryStatus, err);
             return;
         }
     }
@@ -278,13 +278,15 @@ void WirelessTimeline::captureFileReadFinished()
     zoom_level = 0;
 
     show();
-    selectedFrameChanged(0);
+    selectedFrameChanged(QList<int>());
     // TODO: show or ungrey the toolbar controls
     update();
 }
 
 void WirelessTimeline::appInitialized()
 {
+    connect(wsApp->mainWindow(), SIGNAL(framesSelected(QList<int>)), this, SLOT(selectedFrameChanged(QList<int>)));
+
     GString *error_string;
     error_string = register_tap_listener("wlan_radio_timeline", this, NULL, TL_REQUIRES_NOTHING, tap_timeline_reset, tap_timeline_packet, NULL/*tap_draw_cb tap_draw*/, NULL);
     if (error_string) {
@@ -327,18 +329,10 @@ WirelessTimeline::WirelessTimeline(QWidget *parent) : QWidget(parent)
     last = NULL;
     capfile = NULL;
 
-    radio_packet_list = g_hash_table_new(g_direct_hash, g_direct_equal);
+    radio_packet_list = NULL;
     connect(wsApp, SIGNAL(appInitialized()), this, SLOT(appInitialized()));
 }
 
-WirelessTimeline::~WirelessTimeline()
-{
-    if (radio_packet_list != NULL)
-    {
-        g_hash_table_destroy(radio_packet_list);
-    }
-}
-
 void WirelessTimeline::setPacketList(PacketList *packet_list)
 {
     this->packet_list = packet_list;
