@@ -8,8 +8,6 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifdef _WIN32
-
 #include "config.h"
 
 #include <tchar.h>
@@ -21,7 +19,7 @@
 #include <richedit.h>
 #include <strsafe.h>
 
-#include "globals.h"
+#include "file.h"
 
 #include "wsutil/file_util.h"
 #include "wsutil/str_util.h"
@@ -73,7 +71,6 @@ static TCHAR *FILE_EXT_EXPORT[] =
 
 static UINT_PTR CALLBACK open_file_hook_proc(HWND of_hwnd, UINT ui_msg, WPARAM w_param, LPARAM l_param);
 static UINT_PTR CALLBACK save_as_file_hook_proc(HWND of_hwnd, UINT ui_msg, WPARAM w_param, LPARAM l_param);
-static UINT_PTR CALLBACK save_as_statstree_hook_proc(HWND of_hwnd, UINT ui_msg, WPARAM w_param, LPARAM l_param);
 static UINT_PTR CALLBACK export_specified_packets_file_hook_proc(HWND of_hwnd, UINT ui_msg, WPARAM w_param, LPARAM l_param);
 static UINT_PTR CALLBACK merge_file_hook_proc(HWND mf_hwnd, UINT ui_msg, WPARAM w_param, LPARAM l_param);
 static UINT_PTR CALLBACK export_file_hook_proc(HWND of_hwnd, UINT ui_msg, WPARAM w_param, LPARAM l_param);
@@ -226,95 +223,6 @@ win32_open_file (HWND h_wnd, const wchar_t *title, GString *file_name, unsigned
     return gofn_ok;
 }
 
-check_savability_t
-win32_check_save_as_with_comments(HWND parent, capture_file *cf, int file_type)
-{
-    guint32        comment_types;
-    gint           response;
-
-    /* What types of comments do we have? */
-    comment_types = cf_comment_types(cf);
-
-    /* Does the file's format support all the comments we have? */
-    if (wtap_dump_supports_comment_types(file_type, comment_types)) {
-        /* Yes.  Let the save happen; we can save all the comments, so
-           there's no need to delete them. */
-        return SAVE;
-    }
-
-    /* No. Are there formats in which we can write this file that
-       supports all the comments in this file? */
-    if (wtap_dump_can_write(cf->linktypes, comment_types)) {
-        /* Yes.  Offer the user a choice of "Save in a format that
-           supports comments", "Discard comments and save in the
-           format you selected", or "Cancel", meaning "don't bother
-           saving the file at all".
-
-           XXX - given that we no longer support releases prior to
-           Windows Vista, we should use a task dialog:
-
-               https://docs.microsoft.com/en-us/windows/win32/controls/bumper-task-dialog-task-dialogs-reference
-
-           created with TaskDialogIndirect():
-
-               https://docs.microsoft.com/en-us/windows/win32/api/commctrl/nf-commctrl-taskdialogindirect
-
-           because the TASKDIALOGCONFIG structure
-
-               https://docs.microsoft.com/en-us/windows/win32/api/commctrl/ns-commctrl-taskdialogconfig
-
-           supports adding custom buttons, with custom labels, unlike
-           a MessageBox(), which doesn't appear to offer a clean way to
-           do that. */
-        response = MessageBox(parent,
-  _T("The capture has comments, but the file format you chose ")
-  _T("doesn't support comments.  Do you want to discard the comments ")
-  _T("and save in the format you chose?"),
-                              _T("Wireshark: Save File As"),
-                              MB_YESNOCANCEL|MB_ICONWARNING|MB_DEFBUTTON2);
-    } else {
-        /* No.  Offer the user a choice of "Discard comments and
-           save in the format you selected" or "Cancel".
-
-           XXX - see rant above. */
-        response = MessageBox(parent,
-  _T("The capture has comments, but no file format in which it ")
-  _T("can be saved supports comments.  Do you want to discard ")
-  _T("the comments and save in the format you chose?"),
-                              _T("Wireshark: Save File As"),
-                              MB_OKCANCEL|MB_ICONWARNING|MB_DEFBUTTON2);
-    }
-
-    switch (response) {
-
-    case IDNO: /* "No" means "Save in another format" in the first dialog */
-        /* OK, the only other format we support is pcapng.  Make that
-           the one and only format in the combo box, and return to
-           let the user continue with the dialog.
-
-           XXX - removing all the formats from the combo box will clear
-           the compressed checkbox; get the current value and restore
-           it.
-
-           XXX - we know pcapng can be compressed; if we ever end up
-           supporting saving comments in a format that *can't* be
-           compressed, such as NetMon format, we must check this. */
-        /* XXX - need a compressed checkbox here! */
-        return SAVE_IN_ANOTHER_FORMAT;
-
-    case IDYES: /* "Yes" means "Discard comments and save" in the first dialog */
-    case IDOK:  /* "OK" means "Discard comments and save" in the second dialog */
-        /* Save without the comments and, if that succeeds, delete the
-           comments. */
-        return SAVE_WITHOUT_COMMENTS;
-
-    case IDCANCEL:
-    default:
-        /* Just give up. */
-        return CANCELLED;
-    }
-}
-
 gboolean
 win32_save_as_file(HWND h_wnd, const wchar_t *title, capture_file *cf, GString *file_name, int *file_type,
                    wtap_compression_type *compression_type,
@@ -398,58 +306,6 @@ win32_save_as_file(HWND h_wnd, const wchar_t *title, capture_file *cf, GString *
     return gsfn_ok;
 }
 
-gboolean win32_save_as_statstree(HWND h_wnd, GString *file_name, int *file_type)
-{
-    OPENFILENAME *ofn;
-    TCHAR  file_name16[MAX_PATH] = _T("");
-    int    ofnsize = sizeof(OPENFILENAME);
-    BOOL gsfn_ok;
-
-    if (!file_name || !file_type)
-        return FALSE;
-
-    if (file_name->len > 0) {
-        StringCchCopy(file_name16, MAX_PATH, utf_8to16(file_name->str));
-    }
-
-    ofn = g_malloc0(sizeof(OPENFILENAME));
-
-    ofn->lStructSize = ofnsize;
-    ofn->hwndOwner = h_wnd;
-    ofn->hInstance = (HINSTANCE) GetWindowLongPtr(h_wnd, GWLP_HINSTANCE);
-    ofn->lpstrFilter = _T("Plain text file (.txt)\0*.txt\0Comma separated values (.csv)\0*.csv\0XML document (.xml)\0*.xml\0YAML document (.yaml)\0*.yaml\0");
-    ofn->lpstrCustomFilter = NULL;
-    ofn->nMaxCustFilter = 0;
-    ofn->nFilterIndex = 1;  /* the first entry is the best match; 1-origin indexing */
-    ofn->lpstrFile = file_name16;
-    ofn->nMaxFile = MAX_PATH;
-    ofn->lpstrFileTitle = NULL;
-    ofn->nMaxFileTitle = 0;
-    ofn->lpstrInitialDir = utf_8to16(get_last_open_dir());
-    ofn->lpstrTitle = _T("Wireshark: Save stats tree as ...");
-    ofn->Flags = OFN_ENABLESIZING  | OFN_ENABLETEMPLATE  | OFN_EXPLORER        |
-                 OFN_NOCHANGEDIR   | OFN_OVERWRITEPROMPT | OFN_HIDEREADONLY |
-                 OFN_PATHMUSTEXIST | OFN_ENABLEHOOK;
-    ofn->lpstrDefExt = NULL;
-    ofn->lpfnHook = save_as_statstree_hook_proc;
-    ofn->lpTemplateName = _T("WIRESHARK_SAVEASSTATSTREENAME_TEMPLATE");
-
-    HANDLE save_da_ctx = set_thread_per_monitor_v2_awareness();
-    gsfn_ok = GetSaveFileName(ofn);
-    revert_thread_per_monitor_v2_awareness(save_da_ctx);
-
-    if (gsfn_ok) {
-        g_string_printf(file_name, "%s", utf_16to8(file_name16));
-        /* What file format was specified? */
-        *file_type = ofn->nFilterIndex - 1;
-    }
-
-    g_sf_hwnd = NULL;
-    g_free( (void *) ofn);
-    return gsfn_ok;
-}
-
-
 gboolean
 win32_export_specified_packets_file(HWND h_wnd, const wchar_t *title,
                                     capture_file *cf,
@@ -822,7 +678,6 @@ format_handle_wm_initdialog(HWND dlg_hwnd, print_args_t *args) {
             break;
         case print_dissections_expanded:
             SendMessage(cur_ctrl, CB_SETCURSEL, 2, 0);
-            break;
         default:
             g_assert_not_reached();
     }
@@ -1061,6 +916,11 @@ filter_tb_syntax_check(HWND hwnd, TCHAR *filter_text) {
     g_free(strval);
 }
 
+static gint alpha_sort(gconstpointer a, gconstpointer b)
+{
+    return g_ascii_strcasecmp(*(const char **)a, *(const char **)b);
+}
+
 static UINT_PTR CALLBACK
 open_file_hook_proc(HWND of_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
     HWND      cur_ctrl, parent;
@@ -1076,11 +936,27 @@ open_file_hook_proc(HWND of_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
                 SetWindowText(cur_ctrl, utf_8to16(g_dfilter_str));
             }
 
+            /* Put Auto, as well as pcap and pcapng (which are the first two entries in
+               open_routines), at the top of the file type list. */
             cur_ctrl = GetDlgItem(of_hwnd, EWFD_FORMAT_TYPE);
             SendMessage(cur_ctrl, CB_ADDSTRING, 0, (WPARAM) _T("Automatically detect file type"));
-            for (i = 0; open_routines[i].name != NULL; i += 1) {
+            for (i = 0; i < 2; i += 1) {
                 SendMessage(cur_ctrl, CB_ADDSTRING, 0, (WPARAM) utf_8to16(open_routines[i].name));
             }
+            /* Generate a sorted list of the remaining file types.
+               The magic number 60 is a rough starting point for how big the
+               GPtrArray should start. It'll automatically grow if needed, so
+               the exact number isn't critical. (This is good, because we don't have
+               an easy way to get the exact number.) */
+            GPtrArray *routine_names = g_ptr_array_sized_new(60);
+            for ( /* keep using i */ ; open_routines[i].name != NULL; i += 1) {
+                g_ptr_array_add(routine_names, (gpointer)open_routines[i].name);
+            }
+            g_ptr_array_sort(routine_names, alpha_sort);
+            for (guint i = 0; i < routine_names->len; i += 1) {
+                SendMessage(cur_ctrl, CB_ADDSTRING, 0, (WPARAM) utf_8to16((const char *)g_ptr_array_index(routine_names, i)));
+            }
+            g_ptr_array_free(routine_names, TRUE);
             SendMessage(cur_ctrl, CB_SETCURSEL, 0, 0);
 
             preview_set_file_info(of_hwnd, NULL);
@@ -1096,6 +972,20 @@ open_file_hook_proc(HWND of_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
                     cur_ctrl = GetDlgItem(of_hwnd, EWFD_FORMAT_TYPE);
                     g_format_type = (unsigned int) SendMessage(cur_ctrl, CB_GETCURSEL, 0, 0);
 
+                    /* The list of file formats is sorted. Get the format by name. */
+                    guint label_len;
+                    label_len = (guint) SendMessage(cur_ctrl, CB_GETLBTEXTLEN, (WPARAM) g_format_type, 0);
+                    if (label_len != CB_ERR) {
+                        TCHAR *label = g_malloc((label_len+1)*sizeof(TCHAR));
+                        SendMessage(cur_ctrl, CB_GETLBTEXT, (WPARAM) g_format_type, (LPARAM) label);
+                        g_format_type = open_info_name_to_type(utf_16to8(label));
+                        g_free(label);
+                    }
+                    else {
+                        /* Problem, fall back on automatic */
+                        g_format_type = WTAP_TYPE_AUTO;
+                    }
+
                     break;
                 case CDN_SELCHANGE:
                     /* This _almost_ works correctly. We need to handle directory
@@ -1328,57 +1218,8 @@ build_file_save_type_list(GArray *savable_file_types) {
     return (TCHAR *) g_array_free(sa, FALSE /*free_segment*/);
 }
 
-
-#if 0
-static void
-build_file_format_list(HWND sf_hwnd) {
-    HWND  format_cb;
-    int   ft;
-    guint file_index;
-    guint item_to_select;
-    gchar *s;
-
-    /* Default to the first supported file type, if the file's current
-       type isn't supported. */
-    item_to_select = 0;
-
-    format_cb = GetDlgItem(sf_hwnd, EWFD_FILE_TYPE_COMBO);
-    SendMessage(format_cb, CB_RESETCONTENT, 0, 0);
-
-    /* Check all file types. */
-    file_index = 0;
-    for (ft = 0; ft < WTAP_NUM_FILE_TYPES; ft++) {
-        if (ft == WTAP_FILE_UNKNOWN)
-            continue;  /* not a real file type */
-
-        if (!packet_range_process_all(g_range) || ft != cfile.cd_t) {
-            /* not all unfiltered packets or a different file type.  We have to use Wiretap. */
-            if (!wtap_can_save_with_wiretap(ft, cfile.linktypes))
-                continue;       /* We can't. */
-        }
-
-        /* OK, we can write it out in this type. */
-        if(wtap_file_extensions_string(ft) != NULL) {
-            s = g_strdup_printf("%s (%s)", wtap_file_type_string(ft), wtap_file_extensions_string(ft));
-        } else {
-            s = g_strdup_printf("%s (" ALL_FILES_WILDCARD ")", wtap_file_type_string(ft));
-        }
-        SendMessage(format_cb, CB_ADDSTRING, 0, (LPARAM) utf_8to16(s));
-        g_free(s);
-        SendMessage(format_cb, CB_SETITEMDATA, (LPARAM) file_index, (WPARAM) ft);
-        if (ft == g_filetype) {
-            /* Default to the same format as the file, if it's supported. */
-            item_to_select = file_index;
-        }
-        file_index++;
-    }
-
-    SendMessage(format_cb, CB_SETCURSEL, (WPARAM) item_to_select, 0);
-}
-#endif
-
 static UINT_PTR CALLBACK
-save_as_file_hook_proc(HWND sf_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
+save_as_file_hook_proc(HWND sf_hwnd, UINT msg, WPARAM w_param _U_, LPARAM l_param) {
     HWND           cur_ctrl;
     OFNOTIFY      *notify = (OFNOTIFY *) l_param;
     /*int            new_filetype, file_index;*/
@@ -1401,46 +1242,6 @@ save_as_file_hook_proc(HWND sf_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
             break;
         }
         case WM_COMMAND:
-            cur_ctrl = (HWND) l_param;
-
-            switch (w_param) {
-#if 0
-                case (CBN_SELCHANGE << 16) | EWFD_FILE_TYPE_COMBO:
-                    file_index = SendMessage(cur_ctrl, CB_GETCURSEL, 0, 0);
-                    if (file_index != CB_ERR) {
-                        new_filetype = SendMessage(cur_ctrl, CB_GETITEMDATA, (WPARAM) file_index, 0);
-                        if (new_filetype != CB_ERR) {
-                            if (g_filetype != new_filetype) {
-                                if (wtap_can_save_with_wiretap(new_filetype, cfile.linktypes)) {
-                                    cur_ctrl = GetDlgItem(sf_hwnd, EWFD_CAPTURED_BTN);
-                                    EnableWindow(cur_ctrl, TRUE);
-                                    cur_ctrl = GetDlgItem(sf_hwnd, EWFD_DISPLAYED_BTN);
-                                    EnableWindow(cur_ctrl, TRUE);
-                                } else {
-                                    cur_ctrl = GetDlgItem(sf_hwnd, EWFD_CAPTURED_BTN);
-                                    SendMessage(cur_ctrl, BM_SETCHECK, 0, 0);
-                                    EnableWindow(cur_ctrl, FALSE);
-                                    cur_ctrl = GetDlgItem(sf_hwnd, EWFD_DISPLAYED_BTN);
-                                    EnableWindow(cur_ctrl, FALSE);
-                                }
-                                g_filetype = new_filetype;
-                                cur_ctrl = GetDlgItem(sf_hwnd, EWFD_GZIP_CB);
-                                if (wtap_dump_can_compress(file_type)) {
-                                    EnableWindow(cur_ctrl);
-                                } else {
-                                    g_compressed = FALSE;
-                                    DisableWindow(cur_ctrl);
-                                }
-                                SendMessage(cur_ctrl, BM_SETCHECK, g_compressed, 0);
-
-                            }
-                        }
-                    }
-                    break;
-#endif
-                default:
-                    break;
-            }
             break;
         case WM_NOTIFY:
             switch (notify->hdr.code) {
@@ -1486,26 +1287,6 @@ save_as_file_hook_proc(HWND sf_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
     return 0;
 }
 
-static UINT_PTR CALLBACK
-save_as_statstree_hook_proc(HWND sf_hwnd, UINT msg, WPARAM w_param _U_, LPARAM l_param _U_) {
-
-    switch(msg) {
-        case WM_INITDIALOG:
-            g_sf_hwnd = sf_hwnd;
-            break;
-
-        case WM_COMMAND:
-            break;
-
-        case WM_NOTIFY:
-            break;
-
-        default:
-            break;
-    }
-    return 0;
-}
-
 #define RANGE_TEXT_MAX 128
 static UINT_PTR CALLBACK
 export_specified_packets_file_hook_proc(HWND sf_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
@@ -1533,37 +1314,7 @@ export_specified_packets_file_hook_proc(HWND sf_hwnd, UINT msg, WPARAM w_param,
         }
         case WM_COMMAND:
             cur_ctrl = (HWND) l_param;
-
-            switch (w_param) {
-#if 0
-                case (CBN_SELCHANGE << 16) | EWFD_FILE_TYPE_COMBO:
-                    file_index = SendMessage(cur_ctrl, CB_GETCURSEL, 0, 0);
-                    if (file_index != CB_ERR) {
-                        new_filetype = SendMessage(cur_ctrl, CB_GETITEMDATA, (WPARAM) file_index, 0);
-                        if (new_filetype != CB_ERR) {
-                            if (g_filetype != new_filetype) {
-                                if (wtap_can_save_with_wiretap(new_filetype, cfile.linktypes)) {
-                                    cur_ctrl = GetDlgItem(sf_hwnd, EWFD_CAPTURED_BTN);
-                                    EnableWindow(cur_ctrl, TRUE);
-                                    cur_ctrl = GetDlgItem(sf_hwnd, EWFD_DISPLAYED_BTN);
-                                    EnableWindow(cur_ctrl, TRUE);
-                                } else {
-                                    cur_ctrl = GetDlgItem(sf_hwnd, EWFD_CAPTURED_BTN);
-                                    SendMessage(cur_ctrl, BM_SETCHECK, 0, 0);
-                                    EnableWindow(cur_ctrl, FALSE);
-                                    cur_ctrl = GetDlgItem(sf_hwnd, EWFD_DISPLAYED_BTN);
-                                    EnableWindow(cur_ctrl, FALSE);
-                                }
-                                g_filetype = new_filetype;
-                            }
-                        }
-                    }
-                    break;
-#endif
-                default:
-                    range_handle_wm_command(sf_hwnd, cur_ctrl, w_param, g_range);
-                    break;
-            }
+            range_handle_wm_command(sf_hwnd, cur_ctrl, w_param, g_range);
             break;
         case WM_NOTIFY:
             switch (notify->hdr.code) {
@@ -2045,8 +1796,6 @@ export_file_hook_proc(HWND ef_hwnd, UINT msg, WPARAM w_param, LPARAM l_param) {
     return 0;
 }
 
-#endif // _WIN32
-
 /*
  * Editor modelines
  *
